@@ -4,6 +4,7 @@ import (
 	"bufio"
 	"flag"
 	"fmt"
+	"path"
 	"strings"
 
 	"github.com/spf13/cobra"
@@ -11,35 +12,35 @@ import (
 
 	"k8s.io/cli-runtime/pkg/genericclioptions"
 	kclientcmd "k8s.io/client-go/tools/clientcmd"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/annotate"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/apiresources"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/apply"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/attach"
+	"k8s.io/kubectl/pkg/cmd/annotate"
+	"k8s.io/kubectl/pkg/cmd/apiresources"
+	"k8s.io/kubectl/pkg/cmd/apply"
+	"k8s.io/kubectl/pkg/cmd/attach"
+	"k8s.io/kubectl/pkg/cmd/autoscale"
+	"k8s.io/kubectl/pkg/cmd/clusterinfo"
+	"k8s.io/kubectl/pkg/cmd/completion"
+	"k8s.io/kubectl/pkg/cmd/config"
+	kcreate "k8s.io/kubectl/pkg/cmd/create"
+	"k8s.io/kubectl/pkg/cmd/delete"
+	"k8s.io/kubectl/pkg/cmd/describe"
+	"k8s.io/kubectl/pkg/cmd/edit"
+	"k8s.io/kubectl/pkg/cmd/exec"
+	"k8s.io/kubectl/pkg/cmd/explain"
+	"k8s.io/kubectl/pkg/cmd/label"
+	"k8s.io/kubectl/pkg/cmd/patch"
+	"k8s.io/kubectl/pkg/cmd/plugin"
+	"k8s.io/kubectl/pkg/cmd/portforward"
+	"k8s.io/kubectl/pkg/cmd/proxy"
+	"k8s.io/kubectl/pkg/cmd/replace"
+	"k8s.io/kubectl/pkg/cmd/run"
+	"k8s.io/kubectl/pkg/cmd/scale"
+	kcmdutil "k8s.io/kubectl/pkg/cmd/util"
+	kwait "k8s.io/kubectl/pkg/cmd/wait"
+	"k8s.io/kubectl/pkg/util/templates"
 	kcmdauth "k8s.io/kubernetes/pkg/kubectl/cmd/auth"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/autoscale"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/clusterinfo"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/completion"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/config"
 	"k8s.io/kubernetes/pkg/kubectl/cmd/convert"
 	"k8s.io/kubernetes/pkg/kubectl/cmd/cp"
-	kcreate "k8s.io/kubernetes/pkg/kubectl/cmd/create"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/delete"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/describe"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/edit"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/exec"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/explain"
 	kget "k8s.io/kubernetes/pkg/kubectl/cmd/get"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/label"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/patch"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/plugin"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/portforward"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/proxy"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/replace"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/run"
-	"k8s.io/kubernetes/pkg/kubectl/cmd/scale"
-	kcmdutil "k8s.io/kubernetes/pkg/kubectl/cmd/util"
-	kwait "k8s.io/kubernetes/pkg/kubectl/cmd/wait"
-	"k8s.io/kubernetes/pkg/kubectl/util/templates"
 
 	"github.com/openshift/oc/pkg/cli/create"
 	cmdutil "github.com/openshift/oc/pkg/helpers/cmd"
@@ -423,7 +424,16 @@ var (
 
 // NewCmdConfig is a wrapper for the Kubernetes cli config command
 func NewCmdConfig(fullName, name string, f kcmdutil.Factory, streams genericclioptions.IOStreams) *cobra.Command {
-	pathOptions := kclientcmd.NewDefaultPathOptions()
+	pathOptions := &kclientcmd.PathOptions{
+		GlobalFile:       kclientcmd.RecommendedHomeFile,
+		EnvVar:           kclientcmd.RecommendedConfigPathEnvVar,
+		ExplicitFileFlag: genericclioptions.OpenShiftKubeConfigFlagName,
+
+		GlobalFileSubpath: path.Join(kclientcmd.RecommendedHomeDir, kclientcmd.RecommendedFileName),
+
+		LoadingRules: kclientcmd.NewDefaultClientConfigLoadingRules(),
+	}
+	pathOptions.LoadingRules.DoNotResolvePaths = true
 
 	cmd := config.NewCmdConfig(f, pathOptions, streams)
 	cmd.Short = "Change configuration files for the client"
