@@ -1,8 +1,8 @@
 package originpolymorphichelpers
 
 import (
-	"k8s.io/kubernetes/pkg/kubectl/generate"
-	"k8s.io/kubernetes/pkg/kubectl/generate/versioned"
+	"k8s.io/kubectl/pkg/generate"
+	"k8s.io/kubectl/pkg/generate/versioned"
 
 	deploymentcmd "github.com/openshift/oc/pkg/helpers/originpolymorphichelpers/deploymentconfigs"
 	routegen "github.com/openshift/oc/pkg/helpers/route/generator"
